from setuptools import setup

setup(
    name="NoraCalculator",
    version="0.0.1",
    author="Wellington Nora",
    author_email="wellington_nora94@hotmail.com",
    url="https://github.com/wjnnora/SamplePyPi",
    description="An example package PyPi using math functions.",
    packages=["NoraCalculator"],
    zip_safe=False
)